@@ -21,17 +21,21 @@ class PyPIFrontend(upt.Frontend):
     name = 'pypi'
 
     @staticmethod
-    def get_archive_url(release, kind):
+    def get_archive_info(release, kind):
         for elt in release:
             if elt['packagetype'] == kind:
-                return elt['url']
+                digests = elt.get('digests', {})
+                return (elt['url'], elt.get('size', 0),
+                        digests.get('md5'), digests.get('sha256'))
         raise ValueError(f'No archive of type "{kind}" could be found')
 
     def get_sdist_archive_url(self, release):
-        return self.get_archive_url(release, 'sdist')
+        url, _, _, _ = self.get_archive_info(release, 'sdist')
+        return url
 
     def get_wheel_url(self, release):
-        return self.get_archive_url(release, 'bdist_wheel')
+        url, _, _, _ = self.get_archive_info(release, 'bdist_wheel')
+        return url
 
     @staticmethod
     def _string_req_to_upt_pkg_req(string_req):
@@ -354,6 +358,11 @@ class PyPIFrontend(upt.Frontend):
                     licenses.append(upt.licenses.guess_from_file(path))
         return licenses
 
+    def get_archives(self, release):
+        url, size, md5, sha256 = self.get_archive_info(release, 'sdist')
+        archive = upt.Archive(url, size=size, md5=md5, sha256=sha256)
+        return [archive]
+
     def parse(self, pkg_name):
         url = f'https://pypi.org/pypi/{pkg_name}/json'
         r = requests.get(url)
@@ -369,5 +378,6 @@ class PyPIFrontend(upt.Frontend):
             'description': self.json['info']['description'],
             'requirements': requirements,
             'licenses': self.guess_licenses(self.json['releases'][version]),
+            'archives': self.get_archives(self.json['releases'][version]),
         }
         return PyPIPackage(pkg_name, version, **d)
